@@ -2,6 +2,8 @@ import java.util.Date
 import org.gradle.crypto.checksum.Checksum
 import org.jreleaser.model.Active
 import org.jreleaser.model.Distribution
+import org.apache.tools.ant.filters.ReplaceTokens
+
 
 plugins {
   id("edu.sc.seis.version-class") version "1.4.1"
@@ -30,8 +32,12 @@ application {
 }
 
 group = "edu.sc.seis"
-version = "3.1.1-SNAPSHOT"
-val zenodo_rel_id = "10794858"
+version = "3.2.0-SNAPSHOT"
+val ver_split = project.getVersion().toString().split(".")
+val short_version = ver_split[0]+"."+ver_split[1]
+val copyright = "2025"
+val zenodo_rel_id = "16884103" // latest version
+val zenodo_all_id = "10794857" // all versions
 val doifile = "src/doc/sphinx/source/zenodo_id_num.txt"
 
 jreleaser {
@@ -117,6 +123,32 @@ tasks.register("zenodoDoi") {
   File(doifile).writeText(""+zenodo_rel_id)
 }
 
+tasks.register<Copy>("zenodoDoiReadme") {
+  inputs.files("build.gradle.kts")
+  from("src/doc/pages/index.md")
+  into("docs")
+  filter<ReplaceTokens>("tokens" to mapOf(
+    "version" to project.version,
+    "short_version" to short_version,
+    "copyright" to copyright,
+    "zenodo_all_id" to zenodo_all_id,
+    "zenodo_rel_id" to zenodo_rel_id))
+}
+tasks.register<Copy>("copyReadme") {
+  dependsOn("zenodoDoiReadme")
+  from("docs/index.md")
+  into(".")
+  rename("index.md", "README.md")
+}
+
+tasks.register<Exec>("readmeToHtml") {
+  workingDir("docs")
+  commandLine("/usr/bin/env", "-S", "myst-docutils-demo", "index.md", "index.html")
+  inputs.files(tasks.named("zenodoDoiReadme"))
+  outputs.files(file("docs/index.html"))
+  dependsOn("zenodoDoiReadme")
+}
+
 distributions {
   main {
     distributionBaseName = "TauP"
@@ -362,11 +394,17 @@ tasks.register<JavaExec>("genCmdLineTestFiles") {
     dependsOn += tasks.getByName("genAk135Plots")
     outputs.files(fileTree("build/cmdLineTest"))
 }
-tasks.register<Sync>("copyCmdLineTestFiles") {
+tasks.register<Sync>("fullCopyCmdLineTestFiles") {
   from(tasks.getByName("genCmdLineTestFiles").outputs)
   into("src/test/resources/edu/sc/seis/TauP/cmdLineTest")
   dependsOn("genCmdLineTestFiles")
 }
+tasks.register<Exec>("copyCmdLineTestFiles") {
+  commandLine("./src/util/onlyversiondiff.py")
+  dependsOn("genCmdLineTestFiles")
+  dependsOn("genCmdLineHelpFiles")
+}
+
 tasks.get("test").mustRunAfter("copyCmdLineTestFiles")
 tasks.get("jar").mustRunAfter("copyCmdLineTestFiles")
 tasks.get("distTar").mustRunAfter("copyCmdLineTestFiles")
@@ -386,6 +424,25 @@ tasks.register<Sync>("copyCmdLineHelpFiles") {
   dependsOn("genCmdLineHelpFiles")
 }
 
+tasks.register<Copy>("copyDocExampleData") {
+  from("src/example/data")
+  into("build/docExamples")
+}
+tasks.register<JavaExec>("genDocExampleFiles") {
+  inputs.files("build.gradle.kts") // for version.json
+  description = "generate TauP doc example output files"
+  classpath = sourceSets.getByName("test").runtimeClasspath
+  getMainClass().set("edu.sc.seis.TauP.cmdline.GenDocExamples")
+  dependsOn += tasks.getByName("testClasses")
+  dependsOn += tasks.getByName("copyDocExampleData")
+  outputs.files(fileTree("build/docExamples"))
+}
+tasks.register<Sync>("copyDocExampleFiles") {
+  from(tasks.getByName("genDocExampleFiles").outputs)
+  into("src/doc/sphinx/source/examples")
+  dependsOn("genDocExampleFiles")
+}
+
 tasks.register<Sync>("copyProgramExampleFiles") {
   from("src/example/java/edu/sc/seis/example/TimeExample.java")
   from("src/example/python/grab_taup_times.py")
@@ -393,6 +450,7 @@ tasks.register<Sync>("copyProgramExampleFiles") {
   into("src/doc/sphinx/source/programming")
 }
 
+
 tasks.register<Sync>("copyStdModelsToSphinx") {
   from("src/main/resources/edu/sc/seis/TauP/StdModels") {
       include("*.tvel")
@@ -430,11 +488,13 @@ tasks.register<Exec>("sphinxMakeHtml") {
   dependsOn("copyProgramExampleFiles")
   dependsOn("copyCmdLineHelpFiles")
   dependsOn("copyStdModelsToSphinx")
+  dependsOn("copyDocExampleFiles")
 }
 tasks.register<Sync>("copySphinxToDocs") {
   from(tasks.named("sphinxMakeHtml"))
   into("docs/manual")
   dependsOn("sphinxMakeHtml")
+  dependsOn("readmeToHtml")
   exclude("_sources")
   exclude(".buildinfo")
 }
@@ -478,8 +538,8 @@ tasks.jar {
 
 
 tasks.withType<Javadoc>() {
-  exclude("src/main/picocli/CommandLine.java")
-  exclude("src/main/picocli/AutoComplete.java")
+  exclude("picocli/CommandLine.java")
+  exclude("picocli/AutoComplete.java")
   //(options as CoreJavadocOptions).addBooleanOption("Xdoclint:none", true)
 }
 
